@@ -3,20 +3,20 @@
  * Horde_Mapi::
  *
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @copyright 2009-2014 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2015 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   Mapi_Utils
  */
 /**
  * Utility functions for dealing with Microsoft MAPI structures.
  *
- * Copyright 2009-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @copyright 2009-2014 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2015 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   Mapi_Utils
  */
@@ -27,7 +27,7 @@ class Horde_Mapi
      *
      * @return boolean  True if endianness is little endian, otherwise false.
      */
-    static public function isLittleEndian()
+    public static function isLittleEndian()
     {
         $testint = 0x00FF;
         $p = pack('S', $testint);
@@ -43,7 +43,7 @@ class Horde_Mapi
      *
      * @return integer  The number, in the reverse byte order.
      */
-    static public function chbo($num)
+    public static function chbo($num)
     {
         $u = unpack('l', strrev(pack('l', $num)));
 
@@ -59,7 +59,7 @@ class Horde_Mapi
      *
      * @return string  The UID
      */
-    static public function getUidFromGoid($goid)
+    public static function getUidFromGoid($goid)
     {
         $goid = base64_decode($goid);
 
@@ -91,7 +91,7 @@ class Horde_Mapi
      *
      * @return string  A Base64 encoded GOID
      */
-    static public function createGoid($uid, $options = array())
+    public static function createGoid($uid, $options = array())
     {
         // Bytes 1 - 16 MUST be equal to the GOID identifier:
         $arrayid = '040000008200E00074C5B7101A82E008';
@@ -135,7 +135,7 @@ class Horde_Mapi
      * @return integer  The unix timestamp.
      * @throws Horde_Mapi_Exception
      */
-    static public function filetimeToUnixtime($ft)
+    public static function filetimeToUnixtime($ft)
     {
         $ft = bin2hex($ft);
         $dtval = substr($ft, 0, 16);        // clip overlength string
@@ -146,7 +146,7 @@ class Horde_Mapi
     }
 
     // swap little-endian to big-endian
-    static protected function _flipEndian($str)
+    protected static function _flipEndian($str)
     {
         // make sure #digits is even
         if ( strlen($str) & 1 )
@@ -160,12 +160,8 @@ class Horde_Mapi
     }
 
     // convert hex string to BC-int
-    static protected function _hexToBcint($str)
+    protected static function _hexToBcint($str)
     {
-        if (!extension_loaded('bcmath')) {
-            throw new Horde_Mapi_Exception('bcmath extension not loaded.');
-        }
-
         $hex = array(
             '0'=>'0',   '1'=>'1',   '2'=>'2',   '3'=>'3',   '4'=>'4',
             '5'=>'5',   '6'=>'6',   '7'=>'7',   '8'=>'8',   '9'=>'9',
@@ -173,28 +169,31 @@ class Horde_Mapi
             'A'=>'10',  'B'=>'11',  'C'=>'12',  'D'=>'13',  'E'=>'14',  'F'=>'15'
         );
 
-        $bci = '0';
+        $bci = new Math_BigInteger('0');
         $len = strlen($str);
         for ($i = 0; $i < $len; ++$i) {
-            $bci = bcmul($bci, '16');
+            $bci = $bci->multiply(new Math_BigInteger('16'));
             $ch = $str[$i];
-            if (isset($hex[$ch]))
-                $bci = bcadd($bci, $hex[$ch]);
+            if (isset($hex[$ch])) {
+                $bci = $bci->add(new Math_BigInteger($hex[$ch]));
+            }
         }
 
         return $bci;
     }
 
-    static protected function _win64ToUnix($bci)
+    /**
+     *
+     * @param  Math_BigInteger $bci
+     * @return string
+     */
+    protected static function _win64ToUnix($bci)
     {
-        if (!extension_loaded('bcmath')) {
-            throw new Horde_Mapi_Exception('bcmath extension not loaded.');
-        }
-
         // Unix epoch as a Windows file date-time value
-        $magicnum = '116444735995904000';
-        $t = bcsub($bci, $magicnum);    // Cast to Unix epoch
-        return bcdiv($t, '10000000', 0);  // Convert from ticks to seconds
+        $t = $bci->subtract(new Math_BigInteger('116444735995904000'));    // Cast to Unix epoch
+        list($quotient, $remainder) = $t->divide(new Math_BigInteger('10000000'));
+
+        return (string)$quotient;
     }
 
 
