@@ -3,14 +3,14 @@
  * Horde_Mapi_Util_Timezone::
  *
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @copyright 2009-2014 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2015 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   Mapi_Utils
  */
 /**
  * Utility functions for dealing with Microsoft MAPI Timezone format.
  *
- * Copyright 2009-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -19,7 +19,7 @@
  * blob inspired by code in the Tine20 Project (http://tine20.org).
  *
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
- * @copyright 2009-2014 Horde LLC (http://www.horde.org)
+ * @copyright 2009-2015 Horde LLC (http://www.horde.org)
  * @author    Michael J Rubinsky <mrubinsk@horde.org>
  * @package   Mapi_Utils
  */
@@ -68,9 +68,9 @@ class Horde_Mapi_Timezone
      *
      * @return array  Hash of offset information
      */
-    static public function getOffsetsFromSyncTZ($data)
+    public static function getOffsetsFromSyncTZ($data)
     {
-        if (PHP_MINOR_VERSION >= 5) {
+        if (version_compare(PHP_VERSION, '5.5', '>=')) {
             $format = 'lbias/Z64stdname/vstdyear/vstdmonth/vstdday/vstdweek/vstdhour/vstdminute/vstdsecond/vstdmillis/'
                 . 'lstdbias/Z64dstname/vdstyear/vdstmonth/vdstday/vdstweek/vdsthour/vdstminute/vdstsecond/vdstmillis/'
                 . 'ldstbias';
@@ -100,7 +100,7 @@ class Horde_Mapi_Timezone
      * @return string  A base64_encoded MAPI Timezone structure suitable
      *                 for transmitting via wbxml.
      */
-    static public function getSyncTZFromOffsets(array $offsets)
+    public static function getSyncTZFromOffsets(array $offsets)
     {
         if (!Horde_Mapi::isLittleEndian()) {
             $offsets['bias'] = Horde_Mapi::chbo($offsets['bias']);
@@ -124,7 +124,7 @@ class Horde_Mapi_Timezone
      *
      * @return array  An offset hash.
      */
-    static public function getOffsetsFromDate(Horde_Date $date)
+    public static function getOffsetsFromDate(Horde_Date $date)
     {
         $offsets = array(
             'bias' => 0,
@@ -151,8 +151,12 @@ class Horde_Mapi_Timezone
         );
 
         $timezone = $date->toDateTime()->getTimezone();
-        list($std, $dst) = self::_getTransitions($timezone, $date);
-        if ($std) {
+        // If transition parsing failed, we won't have a multi-element array.
+        $transitions = self::_getTransitions($timezone, $date);
+        if (!empty($transitions)) {
+            list($std, $dst) = self::_getTransitions($timezone, $date);
+        }
+        if (!empty($std)) {
             $offsets['bias'] = $std['offset'] / 60 * -1;
             if ($dst) {
                 $offsets = self::_generateOffsetsForTransition($offsets, $std, 'std');
@@ -175,7 +179,7 @@ class Horde_Mapi_Timezone
      *
      * @return array  An array containing the the STD and DST transitions
      */
-    static protected function _getTransitions(DateTimeZone $timezone, Horde_Date $date)
+    protected static function _getTransitions(DateTimeZone $timezone, Horde_Date $date)
     {
 
         $std = $dst = array();
@@ -184,6 +188,10 @@ class Horde_Mapi_Timezone
             mktime(24, 0, 0, 12, 31, $date->year)
         );
 
+        if ($transitions === false) {
+            return array();
+        }
+
         foreach ($transitions as $i => $transition) {
             try {
                $d = new Horde_Date($transition['time']);
@@ -218,7 +226,7 @@ class Horde_Mapi_Timezone
      *
      * @return array  A populated offset hash
      */
-    static protected function _generateOffsetsForTransition(array $offsets, array $transition, $type)
+    protected static function _generateOffsetsForTransition(array $offsets, array $transition, $type)
     {
         // We can't use Horde_Date directly here, since it is unable to
         // properly convert to UTC from local ON the exact hour of a std -> dst
@@ -399,7 +407,7 @@ class Horde_Mapi_Timezone
      *                            not occur 5 times
      * @return boolean
      */
-    static protected function _isNthOcurrenceOfWeekdayInMonth($timestamp, $occurence)
+    protected static function _isNthOcurrenceOfWeekdayInMonth($timestamp, $occurence)
     {
         $original = new Horde_Date($timestamp);
         $original->setTimezone('UTC');
